@@ -56,25 +56,23 @@ print "complete. (processed ", scalar(@{$config{filenames}}), " files)\n\n" unle
 
 ####################################################################
 
-sub get_config
-  {
+sub get_config {
     my @ARGV = @{shift()};
     my %args = %{shift()};
 
     if (defined $args{'V'}) {
-      print "\n\nAutoDia - version ".$Autodia::VERSION."(c) copyright 2003 A Trevena\n\n";
-      exit;
+	print "\n\nAutoDia - version ".$Autodia::VERSION."(c) copyright 2003 A Trevena\n\n";
+	exit;
     }
 
 
     $args{'i'} =~ s/\"// if defined $args{'i'};
     $args{'d'} =~ s/\"// if defined $args{'d'};
 
-    if ($args{'h'})
-      {
+    if ($args{'h'}) {
 	print_instructions();
 	exit;
-      }
+    }
 
     my %config = ();
     my @filenames = ();
@@ -82,7 +80,7 @@ sub get_config
     $config{graphviz} = (defined $args{'z'}) ? 1 : 0;
     $config{language} = (defined $args{'l'}) ? $args{'l'} : "perl";
     $config{silent}   = (defined $args{'S'}) ? 1 : 0;
-    $config{graphvizdia} = (defined $args{'Z'}) ? 1 : 0;
+    $config{springgraph} = (defined $args{'Z'}) ? 1 : 0;
     $config{vcg} = (defined $args{'v'}) ? 1 : 0;
 
     $config{singlefile} = (defined $args{'F'}) ? 1 : 0;
@@ -96,11 +94,11 @@ sub get_config
     $config{public} = (defined $args{'H'}) ? 1 : 0;
 
     if ( $args{'m'} || $args{'A'}) {
-      $config{attributes} = 0;
+	$config{attributes} = 0;
     }
 
     if ( $args{'M'} || $args{'a'}) {
-      $config{methods} = 0;
+	$config{methods} = 0;
     }
 
     Autodia->setConfig(\%config);
@@ -108,89 +106,98 @@ sub get_config
     my %file_extensions = %{Autodia->getPattern()};
 
     if (defined $args{'i'}) {
-      my $last;
-      foreach my $filename ( split(" ",$args{'i'}) ) {
-	unless ( -f $filename ) {
-	  if ($last) {
-	    $filename = "$last $filename";
-	    unless (-f $filename) {
-	      warn "cannot find $filename .. ignoring\n";
-	      $last = $filename;
-	      next;
+	my $last;
+	if ($args{l} =~ /^dbi$/i) {
+	    $filenames[0] = $args{'i'};
+	    warn "have file : $filenames[0]\n";
+	} else {
+	    foreach my $filename ( split(" ",$args{'i'}) ) {
+		unless ( -f $filename ) {
+
+		    if ($last) {
+			$filename = "$last $filename";
+			unless (-f $filename) {
+			    warn "cannot find $filename .. ignoring\n";
+			    $last = $filename;
+			    next;
+			}
+		    } else {
+			$last = $filename;
+			warn "cannot find $filename .. ignoring\n";
+			next;
+		    }
+		}
+		undef $last;
+		push(@filenames,$filename);
 	    }
-	  } else {
-	    $last = $filename;
-	    warn "cannot find $filename .. ignoring\n";
-	    next;
-	  }
 	}
-	undef $last;
-	push(@filenames,$filename);
-      }
-    } elsif (defined $args{'d'}) {
-      print "using directory : " , $args{'d'}, "\n" unless ( $config{silent} );
-      my @dirs = split(" ",$args{'d'});
-      if (defined $args{'r'}) {
-	print "recursively searching files..\n" unless ( $config{silent} );
-	find ( { wanted => sub {
-		   unless (-d) {
-		     my $regex = $file_extensions{regex};
-		     push @filenames, $File::Find::name
-		       if ($File::Find::name =~ m/$regex/);
-		   }
-		 },
-		 preprocess => sub {
-		   my @return;
-		   foreach (@_) {
-		     push(@return,$_) unless (m/^.*\/?CVS$/ && $config{skipcvs});
-		   }
-		   return @return;
-		 },
-	       }, @dirs );
-      } else {
-	my @wildcards = @{$file_extensions{wildcards}};
-	print "searching files using wildcards : @wildcards \n" unless ( $config{silent} );
-	foreach my $directory (@dirs) {
-	  if ($directory eq 'CVS' and $config{skipcvs}) {
-	    warn "skipping $directory\n" unless ( $config{silent} );
-	    next;
-	  }
-	  print "searching $directory\n" unless ( $config{silent} );
-	  $directory =~ s|(.*)\/$|$1|;
-	  foreach my $wildcard (@wildcards) {
-	    print "$wildcard" unless ( $config{silent} );
-	    print " .. " , <$directory/*.$wildcard>, " \n";
-	    push @filenames, <$directory/*.$wildcard>;
-	  }
-	}
-      }
-    } elsif (@ARGV) {
-      @filenames = @ARGV;
-    } else {
-      print_instructions();
-      exit;
     }
-
-      $config{filenames}    = \@filenames;
-      $config{use_stdout}   = (defined $args{'O'}) ? 1 : 0;
-      $config{templatefile} = (defined $args{'t'}) ? $args{'t'} : undef;
-      $config{outputfile}   = (defined $args{'o'}) ? $args{'o'} : "autodia.out.xml";
-      $config{no_deps}      = (defined $args{'D'}) ? 1 : 0;
-      $config{sort}         = (defined $args{'s'}) ? 1 : 0;
-
-      my $inputpath = "";
-      if (defined $args{'p'}) {
+    if (defined $args{'d'}) {
+	print "using directory : " , $args{'d'}, "\n" unless ( $config{silent} );
+	my @dirs = split(" ",$args{'d'});
+	if (defined $args{'r'}) {
+	    print "recursively searching files..\n" unless ( $config{silent} );
+	    find ( { wanted => sub {
+			 unless (-d) {
+			     my $regex = $file_extensions{regex};
+			     push @filenames, $File::Find::name
+				 if ($File::Find::name =~ m/$regex/);
+			 }
+		     },
+		     preprocess => sub {
+			 my @return;
+			 foreach (@_) {
+			     push(@return,$_) unless (m/^.*\/?(CVS|RCS)$/ && $config{skipcvs});
+			 }
+			 return @return;
+		     },
+		   }, @dirs );
+	} else {
+	    my @wildcards = @{$file_extensions{wildcards}};
+	    print "searching files using wildcards : @wildcards \n" unless ( $config{silent} );
+	    foreach my $directory (@dirs) {
+		if ($directory =~ m/^(CVS|RCS)/ and $config{skipcvs}) {
+		    warn "skipping $directory\n" unless ( $config{silent} );
+		    next;
+		}
+		print "searching $directory\n" unless ( $config{silent} );
+		$directory =~ s|(.*)\/$|$1|;
+		foreach my $wildcard (@wildcards) {
+		    print "$wildcard" unless ( $config{silent} );
+		    print " .. " , <$directory/*.$wildcard>, " \n";
+		    push @filenames, <$directory/*.$wildcard>;
+		}
+	    }
+	}
+    }
+    my $inputpath = "";
+    if (defined $args{'p'}) {
 	$inputpath = $args{'p'};
 	unless ($inputpath =~ m/\/$/)
-	  {
-	    $inputpath .= "/";
-	  }
-      }
-
-      $config{inputpath}    = $inputpath;
-
-      return \%config;
+	    {
+		$inputpath .= "/";
+	    }
     }
+    $config{inputpath} = $inputpath;
+
+
+    unless (defined $args{'d'} || $args{'i'} || $args{'p'}) {
+	if (@ARGV) {
+	    @filenames = @ARGV;
+	} else {
+	    print_instructions();
+	    exit;
+	}
+    }
+    $config{filenames}    = \@filenames;
+    $config{use_stdout}   = (defined $args{'O'}) ? 1 : 0;
+    $config{templatefile} = (defined $args{'t'}) ? $args{'t'} : undef;
+    $config{outputfile}   = (defined $args{'o'}) ? $args{'o'} : "autodia.out.xml";
+    $config{no_deps}      = (defined $args{'D'}) ? 1 : 0;
+    $config{sort}         = (defined $args{'s'}) ? 1 : 0;
+
+    return \%config;
+}
 
 sub print_instructions {
   print "AutoDia - Automatic Dia XML. Copyright 2001 A Trevena\n\n";
@@ -211,7 +218,8 @@ autodia.pl -l language            : parse source as language (ie: C) and look fo
 autodia.pl -t templatefile        : use templatefile as template (otherwise uses default)
 autodia.pl -l DBI -i "mysql:test:localhost" -U username -P password : use the test database on localhost with username and password as username and password
 autodia.pl -z                     : use graphviz to produce dot, gif, jpg or png output
-autodia.pl -v                     : output VCG digraph for use with VCG
+autodia.pl -Z                     : use springgraph to produce png output
+autodia.pl -v                     : use vcg to output postscript
 autodia.pl -D                     : ignore dependancies (ie do not process or display dependancies)
 autodia.pl -S                     : silent mode, no output to stdout except with -O
 autodia.pl -H                     : show only public/visible methods and attributes
@@ -274,9 +282,11 @@ Helpful information, links and news can be found at the autodia website - http:/
 
 =item C<autodia.pl -l DBI -i "mysql:test:localhost" -U username -P password : use test database on localhost with username and password as username and password>
 
-=item C<autodia.pl -z                     : use graphviz 'yeah, baby!'>
+=item C<autodia.pl -z                     : output via graphviz>
 
-=item C<autodia.pl -v                     : output VCG digraph for use with VCG>
+=item C<autodia.pl -Z                     : output via springgraph>
+
+=item C<autodia.pl -v                     : output via VCG >
 
 =item C<autodia.pl -H                     : show only Public/Visible methods>
 
